summaryrefslogtreecommitdiffhomepage
path: root/Stars45/Intel.h
diff options
context:
space:
mode:
authormilo24x7@gmail.com <milo24x7@gmail.com@076cb2c4-205e-83fd-5cf3-1be9aa105544>2013-07-07 22:08:49 +0000
committermilo24x7@gmail.com <milo24x7@gmail.com@076cb2c4-205e-83fd-5cf3-1be9aa105544>2013-07-07 22:08:49 +0000
commitd17521c8b9085a91d08fecfd0b51bbbf7b1dccac (patch)
tree4673104b47dc68a079cac9f94deefd48dfcb66fa /Stars45/Intel.h
parent1de4b2bdbb019be6f1b7262c3eba5568d7682edd (diff)
downloadstarshatter-d17521c8b9085a91d08fecfd0b51bbbf7b1dccac.zip
starshatter-d17521c8b9085a91d08fecfd0b51bbbf7b1dccac.tar.gz
starshatter-d17521c8b9085a91d08fecfd0b51bbbf7b1dccac.tar.bz2
Updated open source license declaration and fixed some formatting issues.
Diffstat (limited to 'Stars45/Intel.h')
-rw-r--r--Stars45/Intel.h98
1 files changed, 61 insertions, 37 deletions
diff --git a/Stars45/Intel.h b/Stars45/Intel.h
index a582188..611c9d8 100644
--- a/Stars45/Intel.h
+++ b/Stars45/Intel.h
@@ -1,37 +1,61 @@
-/* Project Starshatter 4.5
- Destroyer Studios LLC
- Copyright © 1997-2004. All Rights Reserved.
-
- SUBSYSTEM: Stars.exe
- FILE: Intel.h
- AUTHOR: John DiCamillo
-
-
- OVERVIEW
- ========
-*/
-
-#ifndef Intel_h
-#define Intel_h
-
-#include "Types.h"
-
-// +--------------------------------------------------------------------+
-
-class Intel
-{
-public:
- enum INTEL_TYPE {
- RESERVE = 1, // out-system reserve: this group is not even here
- SECRET, // enemy is completely unaware of this group
- KNOWN, // enemy knows this group is in the system
- LOCATED, // enemy has located at least the lead ship
- TRACKED // enemy is tracking all elements
- };
-
- static int IntelFromName(const char* name);
- static const char* NameFromIntel(int intel);
-};
-
-#endif Intel_h
-
+/* Starshatter OpenSource Distribution
+ Copyright (c) 1997-2004, Destroyer Studios LLC.
+ All Rights Reserved.
+
+ Redistribution and use in source and binary forms, with or without
+ modification, are permitted provided that the following conditions are met:
+
+ * Redistributions of source code must retain the above copyright notice,
+ this list of conditions and the following disclaimer.
+ * Redistributions in binary form must reproduce the above copyright notice,
+ this list of conditions and the following disclaimer in the documentation
+ and/or other materials provided with the distribution.
+ * Neither the name "Destroyer Studios" nor the names of its contributors
+ may be used to endorse or promote products derived from this software
+ without specific prior written permission.
+
+ THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ POSSIBILITY OF SUCH DAMAGE.
+
+ SUBSYSTEM: Stars.exe
+ FILE: Intel.h
+ AUTHOR: John DiCamillo
+
+
+ OVERVIEW
+ ========
+*/
+
+#ifndef Intel_h
+#define Intel_h
+
+#include "Types.h"
+
+// +--------------------------------------------------------------------+
+
+class Intel
+{
+public:
+ enum INTEL_TYPE {
+ RESERVE = 1, // out-system reserve: this group is not even here
+ SECRET, // enemy is completely unaware of this group
+ KNOWN, // enemy knows this group is in the system
+ LOCATED, // enemy has located at least the lead ship
+ TRACKED // enemy is tracking all elements
+ };
+
+ static int IntelFromName(const char* name);
+ static const char* NameFromIntel(int intel);
+};
+
+#endif Intel_h
+